<?php

/**
 * ochStrictrouter - System plugin
 *
 * @version     0.2.1
 * @package     Joomla
 * @subpackage  plg_system_ochstrictrouter
 *
 * @author      Ruud van Lent <info@onlinecommunityhub.nl>
 * @copyright   Copyright (C) 2019 - 2021 Onlinecommunityhub (X-ceed B.V.). All rights reserved.
 * @license     GNU/GPL version 3 or later
 * @link        https://onlinecommunityhub.nl
 */


// No direct access
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use OCH\ochStrictrouter\OchInstallerScriptHelper;

// Include the helper functions only once
JLoader::register('OCH\ochStrictrouter\OchInstallerScriptHelper', __DIR__ . '/helpers/ochinstaller.script.helper.php');

/**
 * Script file to clean up left-overs from previous versions
 * Called from upgrade routine
 *
 * @since  0.0.0
 */
class PlgSystemOchstrictrouterInstallerScript
{
	/**
	 * @var string
	 */
	protected $installedVersion;

	/**
	 * @var array
	 */
	protected $maintenanceVariables;

	/**
	 * Method to run before the install routine.
	 *
	 * @param   string                      $type    The action being performed
	 * @param   JInstallerAdapterComponent  $parent  The class calling this method
	 *
	 * @return  void|boolean
	 */
	public function preflight($type, $parent)
	{
		// Check for minimum required Joomla! version
		if (!OchInstallerScriptHelper::checkMinimumJoomlaVersion($type, $parent))
		{
			// We are not on minimum Joomla! version: get out of here...
			return false;
		}

		$type = strtolower($type);

		if ($type == 'update')
		{
			$this->installedVersion = OchInstallerScriptHelper::getInstalledVersion('plugin', 'ochstrictrouter');
		}
	}

	/**
	 * Code to execute on plugin update, used for cleaning left-overs from previous versions
	 *
	 * @param   object  $adapter  Adapter instance
	 *
	 * @return  void
	 */
	public function update($adapter)
	{
		$application = Factory::getApplication();
		$newVersion = $adapter->manifest->version;

		// Load all maintenance variables
		$this->setMaintenanceVariables();

		// Remove all configured files
		OchInstallerScriptHelper::doMaintenance($this->maintenanceVariables, $this->installedVersion);
	}

	/**
	 * Set the maintenance variables
	 *
	 * @return void
	 */
	public function setMaintenanceVariables()
	{
		$this->maintenanceVariables['remove_files'] = array();

		$this->maintenanceVariables['remove_directories'] = array();

		$this->maintenanceVariables['installation_messages'] = array();

		$this->maintenanceVariables['component_warnings'] = array();

		$this->maintenanceVariables['update_sites'] = array();
	}
}
